/*
 * demo6.c: sample event-driven module showing how to
 *          handle proxy sockets.
 */

#include <unistd.h>

#include "tuxmodule.h"

#ifdef TUXAPI_declare
TUXAPI_declare;
#endif

#define REPLY_HEADER "HTTP/1.0 200 OK\r\nContent-Type: text/html\r\n\r\n"
#define REPLY_HEADER_LEN (sizeof(REPLY_HEADER)-1)

#define REQUEST "GET /mingo/module-test/ HTTP/1.0\r\nHost: localhost\r\n\r\n"

int proxy_fd = -1;

int TUXAPI_handle_events (user_req_t *req)
{
	char buff[10000];
	int ret = TUX_RETURN_USERSPACE_REQUEST, len;

	switch (req->event) {
		/*
		 * A new request starts with event code 0.
		 */
		case 0:
			if (!req->query[0])
				goto abort;
        		write (req->sock, REPLY_HEADER, REPLY_HEADER_LEN);
			req->http_status = 200;

			req->event = 1;
			req->object_addr = (uint64_t)proxy_fd;
			ret = tux(TUX_ACTION_WATCH_PROXY_SOCKET, req);
			write(proxy_fd, REQUEST, sizeof(REQUEST));
			req->object_addr = (uint64_t)proxy_fd;
			ret = tux(TUX_ACTION_WAIT_PROXY_SOCKET, req);
			break;
		case 1:
			len = recv(proxy_fd, buff, 10000, MSG_DONTWAIT);
			if (len == -EAGAIN) {
				/*
				 * We'll wait for more input packets on
				 * the proxy socket.
				 */
				req->event = 1;
				ret = tux(TUX_ACTION_WAIT_PROXY_SOCKET, req);
				break;
			}
			if (len > 0)
				write(req->sock, buff, len);
			ret = tux(TUX_ACTION_FINISH_CLOSE_REQ, req);
			break;
		abort:
			break;
	}
	return ret;
}

void TUXAPI_init (void)
{
	struct sockaddr_in server;
	struct hostent *he = gethostbyname("people.redhat.com");

	if (!he) {
		perror("host error.\n");
		exit(-1);
	}

	server.sin_family = he->h_addrtype;
	server.sin_port = htons(8080);
	server.sin_addr.s_addr = ((unsigned long *)(he->h_addr_list[0]))[0];

	proxy_fd = socket(AF_INET, SOCK_STREAM, 0);

	if (connect(proxy_fd, (struct sockaddr *) &server, sizeof(server)) < 0) {
		perror("connect error.\n");
		exit(-2);
	}
}

